@@ -5,6 +5,7 @@
 #include <kapplication.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <kurlrequester.h>
 
 #include <qimage.h>
 #include <qlineedit.h>
@@ -100,7 +101,7 @@ QWidget *Setup::color()
     QBoxLayout *l = new QVBoxLayout(base,10,0);
 
     grupo[0] = new QGroupBox(base);
-    grupo[0]->setTitle( i18n("Color mapping (non TrueColor displays)"));
+    grupo[0]->setTitle( i18n("Color Mapping (non TrueColor displays)"));
 
     QBoxLayout *l1 = new QVBoxLayout(grupo[0],10,0);
 
@@ -185,22 +186,22 @@ QWidget *Setup::scaling()
     QBoxLayout *l = new QVBoxLayout(base, 10);
 
     label[3] = new QLabel( base );
-    label[3]->setText( i18n("Display scale" ));
+    label[3]->setText( i18n("Display scale:" ));
     label[3]->setMinimumSize( label[3]->sizeHint() );
     l->addWidget(label[3]);
 
     combo[0] = new QComboBox( base );
-    combo[0]->insertItem( i18n("Original size") );
-    combo[0]->insertItem( i18n("Half size") );
-    combo[0]->insertItem( i18n("Double size") );
+    combo[0]->insertItem( i18n("Original Size") );
+    combo[0]->insertItem( i18n("Half Size") );
+    combo[0]->insertItem( i18n("Double Size") );
     combo[0]->insertItem( i18n("Maximized") );
-    combo[0]->insertItem( i18n("Full screen") );
+    combo[0]->insertItem( i18n("Full Screen") );
     combo[0]->setCurrentItem(config->readNumEntry("scale"));
     combo[0]->setMinimumSize( combo[0]->sizeHint() );
     l->addWidget(combo[0]);
 
     botones[2] = new QButtonGroup( base );
-    botones[2]->setTitle( i18n("Full screen") );
+    botones[2]->setTitle( i18n("Full Screen") );
 
     QBoxLayout *l1 = new QVBoxLayout(botones[2], 10, 0);
     l1->addSpacing(10);
@@ -257,19 +258,10 @@ QWidget *Setup::capture()
     label[8]->setMinimumSize( label[8]->sizeHint() );
     l->addWidget(label[8]);
 
-    QBoxLayout *l2 = new QHBoxLayout();
-    l->addLayout(l2);
+    capDirReq = new KURLRequester(config->readEntry("outputDir","~"), base);
+    capDirReq->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    l->addWidget(capDirReq);
 
-    lined[5] = new QLineEdit( base );
-    lined[5]->setText( config->readEntry("outputDir"));
-    lined[5]->setMinimumSize( lined[5]->sizeHint() );
-    l2->addWidget( lined[5] );
-
-    dirButton[1] = new QPushButton( base );
-    dirButton[1]->setText("...");
-    dirButton[1]->setFixedSize( dirButton[1]->sizeHint() );
-    l2->addWidget( dirButton[1] );
-    connect( dirButton[1], SIGNAL(clicked()), SLOT(getCaptureDir()) );
 
     label[9] = new QLabel( base );
     label[9]->setText( i18n("Press 'c' during playback to capture a single frame." ));
@@ -290,7 +282,7 @@ QWidget *Setup::others()
     QBoxLayout *l = new QVBoxLayout(base, 10, 0);
 
     botones[1] = new QButtonGroup( base );
-    botones[1]->setTitle( i18n("Video loading") );
+    botones[1]->setTitle( i18n("Video Loading") );
     //botones[1]->setMinimumSize(10,10,max,90);
 
     QBoxLayout *l1 = new QVBoxLayout(botones[1], 10, 0);
@@ -334,7 +326,7 @@ QWidget *Setup::others()
     l->addWidget( checkBox[4] );
 
     checkBox[5] = new QCheckBox( base );
-    checkBox[5]->setText( i18n("Use Pixmap instead of Image in X11") );
+    checkBox[5]->setText( i18n("Use pixmap instead of image in X11") );
     checkBox[5]->setMinimumSize( checkBox[5]->sizeHint() );
     checkBox[5]->setChecked(config->readBoolEntry("pixmap"));
     l->addWidget( checkBox[5] );
@@ -358,19 +350,10 @@ QWidget *Setup::others()
     label[4]->setMinimumSize( label[4]->sizeHint() );
     l->addWidget( label[4] );
 
-    QBoxLayout *l2 = new QHBoxLayout();
-    l->addLayout(l2);
+    initialDirReq = new KURLRequester(config->readEntry("initialDirectory"), base);
+    initialDirReq->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    l->addWidget(initialDirReq);
 
-    lined[3] = new QLineEdit( base );
-    lined[3]->setText( config->readEntry("initialDirectory"));
-    lined[3]->setMinimumSize( lined[3]->sizeHint() );
-    l2->addWidget( lined[3] );
-
-    dirButton[0] = new QPushButton( base );
-    dirButton[0]->setText("...");
-    dirButton[0]->setFixedSize( dirButton[0]->sizeHint() );
-    l2->addWidget( dirButton[0] );
-    connect( dirButton[0], SIGNAL(clicked()), SLOT(getDir()) );
 
     checkBox[6] = new QCheckBox( base );
     checkBox[6]->setText( i18n("Loop animation") );
@@ -399,19 +382,9 @@ QWidget *Setup::others()
     label[6]->setMinimumSize( label[6]->sizeHint() );
     l->addWidget( label[6] );
 
-    QBoxLayout *l3 = new QHBoxLayout();
-    l->addLayout(l3);
+    binaryReq = new KURLRequester(config->readEntry("executable"), base);
+    l->addWidget(binaryReq);
 
-    lined[4] = new QLineEdit( base );
-    lined[4]->setText( config->readEntry("executable"));
-    lined[4]->setMinimumSize( lined[4]->sizeHint() );
-    l3->addWidget( lined[4] );
-
-    executableButton = new QPushButton( base );
-    executableButton->setText("...");
-    executableButton->setFixedSize( executableButton->sizeHint() );
-    l3->addWidget( executableButton );
-    connect( executableButton, SIGNAL(clicked()), SLOT(getXanimExecutable()) );
 
     l->activate();
     return base;
@@ -445,7 +418,7 @@ void Setup::save()
 
     config->setGroup("capture");
     config->writeEntry("outputFormat",combo[1]->currentText() );
-    config->writeEntry("outputDir",lined[5]->text() );
+    config->writeEntry("outputDir", capDirReq->url() );
 
     config->setGroup("others");
     if (botonRadio[4]->isChecked()) config->writeEntry("loading", 0);
@@ -455,10 +428,10 @@ void Setup::save()
     config->writeEntry("multiBuffer",checkBox[4]->isChecked() );
     config->writeEntry("pixmap",checkBox[5]->isChecked() );
 //    config->writeEntry("visualClass",combo[0]->currentItem() );
-    config->writeEntry("initialDirectory", lined[3]->text() );
+    config->writeEntry("initialDirectory", initialDirReq->url() );
     config->writeEntry("loop",checkBox[6]->isChecked() );
     config->writeEntry("extras",lined[2]->text());
-    config->writeEntry("executable",lined[4]->text());
+    config->writeEntry("executable", binaryReq->url());
     config->writeEntry("autoplay",checkBox[7]->isChecked() );
 
     config->sync();
@@ -469,39 +442,6 @@ Setup::~Setup()
 {
 }
 
-void Setup::getDir()
-{
-   QString s;
-   
-   s=KFileDialog::getExistingDirectory("",0L);
-   if (!s.isEmpty())
-      lined[3]->setText(s);
-}
-
-void Setup::getCaptureDir()
-{
-   QString s;
-   
-   s=KFileDialog::getExistingDirectory("",0L);
-   if (!s.isEmpty())
-      lined[5]->setText(s);
-}
-
-void Setup::getXanimExecutable()
-{
-   KURL url = KFileDialog::getOpenURL("","*|All files (*)",0L,i18n("xanim executable:" ));
-   
-   if( url.isEmpty() )
-     return;
-   
-   if( !url.isLocalFile() )
-   {
-     KMessageBox::sorry( 0L, i18n( "Only local executables allowed." ) );
-     return;
-   }  
-   
-   lined[4]->setText(url.path());
-}
 
 void Setup::actualizeDialog(int rButton)
 {
