@@ -15,6 +15,7 @@ class QPushButton;
 class QSpinBox;
 class QListBox;
 class QComboBox;
+class KURLRequester;
 
 class Setup : public QTabDialog
 {
@@ -34,20 +35,18 @@ private:
     QWidget *capture();
     QWidget *others();
 
+    KURLRequester* binaryReq;
+    KURLRequester* initialDirReq;
+    KURLRequester* capDirReq;
     QLabel *label[10];
     QGroupBox *grupo[1];
     QButtonGroup *botones[3];
     QComboBox *combo[2];
     QListBox *lista[1];
-    QPushButton *dirButton[2];
-    QPushButton *executableButton;
     QSpinBox *spin[1];
 private slots:
     void quit();
     void save();
-    void getDir();
-    void getCaptureDir();
-    void getXanimExecutable();
     void actualizeDialog(int);
     void actualizeDialog1(int);
 };
