@@ -26,6 +26,6 @@
 
 class DrawUtils {
 public:
-	static char *cropText(QPainter *p, const char *text, int maxlen, int& textwidth);
+	static QString cropText(QPainter *p, QString text, int maxlen, int& textwidth);
 };
 #endif
