@@ -28,7 +28,7 @@
 #include <qtimer.h>
 #include <qlabel.h>
 #include <qscrollbar.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <qlayout.h>
 #include <qlistbox.h>
 #include <string>
