@@ -9,12 +9,12 @@
     modify it under the terms of the GNU Library General Public
     License as published by the Free Software Foundation; either
     version 2 of the License, or (at your option) any later version.
-  
+
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Library General Public License for more details.
-   
+
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -45,7 +45,7 @@ void PotiIntMapper::valueChanged(int pos)
 KPoti_impl::KPoti_impl(KPoti *newKPoti /* = 0 */)
 	: KWidget_impl(kpoti = (newKPoti?newKPoti:new KPoti(0,100,1,0)))
 {
-	kpoti->setFixedSize(46,40); 
+	kpoti->setFixedSize(46,40);
 	new PotiIntMapper(this, kpoti);
 	_min = 0; _max = 1; _value = 0;
 	_factor = 1;
@@ -55,13 +55,13 @@ KPoti_impl::KPoti_impl(KPoti *newKPoti /* = 0 */)
 
 string KPoti_impl::caption()
 {
-	return _caption;
+	return _caption.utf8().data();
 }
 
 void KPoti_impl::caption(const string& newText)
 {
-	_caption = newText;
-	kpoti->setName(_caption.c_str());
+	_caption = QString::fromUtf8(newText.c_str());
+	kpoti->setName(_caption.utf8());
 }
 
 string KPoti_impl::color()
@@ -76,7 +76,7 @@ void KPoti_impl::color(const string& newColor)
     {
         QColor qc(_color.c_str());
         kpoti->setColor(qc);
-    }                                                                           
+    }
 }
 
 float KPoti_impl::min()
@@ -162,7 +162,7 @@ float KPoti_impl::convertFromLog(float val)
 {
 	return pow(_logarithmic, val);
 }
-	
+
 void KPoti_impl::applyValue()
 {
 	double dmin = _min;
