@@ -77,8 +77,10 @@ void parseArgs(int argc, char** argv)
 				break;
 			case 'l': test = 2;
 				break;
-      case 'v': verbose = 1; printf("MidiSend %s\n", VERSION );
-        break;
+#ifdef VERSION
+			case 'v': verbose = 1; printf("MidiSend %s\n", VERSION );
+				break;
+#endif
 			case 'f': strncpy(cFileName,optarg,1024);
 				break;
 			default: usage(argv[0]);
