@@ -34,7 +34,7 @@ class Synth_PITCH_SHIFT_impl : virtual public Synth_PITCH_SHIFT_skel,
 protected:
 	float _speed, _frequency;
 
-	static const int MAXDELAY = 44100;
+	enum { MAXDELAY = 44100 };
 	float *dbuffer;
 	float lfopos, b1pos, b2pos, b1inc, b2inc;
 	bool b1reset, b2reset, initialized;
