@@ -106,7 +106,7 @@ void Gui_AUDIO_MANAGER::setParent(QWidget *parent, QBoxLayout *layout)
 
 	listview->addColumn(i18n("Title"),175);
 	listview->addColumn(i18n("Type"),50);
-	listview->addColumn(i18n("Destination"),75);
+	listview->addColumn(i18n("Bus"),75);
 
 	listview->setMinimumSize(300,100);
 
