@@ -24,7 +24,7 @@
 #include <qiomanager.h>
 #include <dispatcher.h>
 #include <qmessagebox.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <qframe.h>
 #include <kmainwindow.h>
 #include <kcmdlineargs.h>
