@@ -25,8 +25,8 @@
 #include <qdialog.h>
 #include <qtimer.h>
 #include <qlabel.h>
-#include <qscrbar.h>
-#include <qlined.h>
+#include <qscrollbar.h>
+#include <qlineedit.h>
 #include <qlayout.h>
 
 class MidiPortDlg :public QDialog {
