@@ -40,11 +40,12 @@ Kaboodle::KaboodleApp::KaboodleApp()
 		if(!url.isMalformed()) openURL = url;
 	}
 
-	new UserInterface(0L, openURL);
+	ui = new UserInterface(0L, openURL);
 }
 
 Kaboodle::KaboodleApp::~KaboodleApp()
 {
+    delete ui;
 }
 
 #include "kaboodleapp.moc"
