@@ -37,6 +37,7 @@ Kaboodle::Player::Player(QObject *parent, const char *name)
 	, engine(new Engine(this))
 	, widget(0)
 	, uncompleted(true)
+	, embedded(false)
 {
 	setInstance(KaboodleFactory::instance());
 
@@ -51,6 +52,7 @@ Kaboodle::Player::Player(QWidget *widgetParent, const char *widgetName,
 	, engine(new Engine(this))
 	, widget(new View(widgetParent, widgetName, this))
 	, uncompleted(true)
+	, embedded(false)
 {
 	setInstance(KaboodleFactory::instance());
 
@@ -90,7 +92,6 @@ bool Kaboodle::Player::openURL(const KURL &f)
 	{
 		uncompleted = false;
 		engine->stop();
-		widget->embed(Arts::PlayObject::null());
 	}
 
 	emit started(0);
@@ -108,8 +109,6 @@ bool Kaboodle::Player::openURL(const KURL &f)
 	pauseAction->setEnabled(false);
 	setState(Stop);
 
-	widget->embed(engine->playObject());
-
 	tickerTimeout();
 	return true;
 }
@@ -214,7 +213,7 @@ void Kaboodle::Player::tickerTimeout(void)
 	if(engine->state() == Stop)
 	{
 		if ( uncompleted )
- 		{
+		{
 			stop();
 			if( isLooping() )
 			{
@@ -226,9 +225,20 @@ void Kaboodle::Player::tickerTimeout(void)
 				emit completed();
 			}
 		}
+		if(embedded)
+		{
+			widget->embed(Arts::PlayObject::null());
+			embedded = false;
+		}
 	}
 	else if(engine->state() != Stop && engine->state() != Empty)
 	{
+		if(!embedded)
+		{
+			widget->embed(engine->playObject());
+			embedded = true;
+		}
+		
 		emit timeout();
 
 		if(extension)
