@@ -33,6 +33,7 @@
 #include <kpropertiesdialog.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
+#include <kurldrag.h>
 #include <qdragobject.h>
 #include <qlayout.h>
 #include <qlcdnumber.h>
@@ -104,16 +105,16 @@ void Kaboodle::UserInterface::fileOpen(void)
 void Kaboodle::UserInterface::dragEnterEvent(QDragEnterEvent *event)
 {
     // accept uri drops only
-    event->accept(QUriDrag::canDecode(event));
+    event->accept(KURLDrag::canDecode(event));
 }
 
 void Kaboodle::UserInterface::dropEvent(QDropEvent *event)
 {
-	QStrList uri;
-	if (QUriDrag::decode(event, uri))
+	KURL::List list;
+	if (KURLDrag::decode(event, list))
 	{
-		char *file = uri.first();
-		if(file) part->openURL(KURL(file));
+		if (!list.isEmpty())
+			part->openURL(list.first());
 	}
 }
 
