@@ -22,10 +22,13 @@
 #include <kprocess.h>
 #include <kmessagebox.h>
 
-#define HAVE_LAME 0
-
 #include <config.h>
 
+// Moved the HAVE_LAME define in order to avoid redefined-warnings.
+#ifndef HAVE_LAME
+#define HAVE_LAME 0
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -52,21 +55,32 @@ typedef Q_INT32 size32;
 #include <qlineedit.h>
 #include <qcheckbox.h>
 
+#if HAVE_LAME
+extern "C"
+{
+#include <lame/lame.h>
+}
+#endif
+
 extern "C"
 {
 #include <cdda_interface.h>
 #include <cdda_paranoia.h>
+}
 
+// Many Linux systems do not define LINUX. It's something else that I
+// can't be bothered to look up just right now.
+#if defined(LINUX) || defined(__linux__)
+extern "C"
+{
 /* This is in support for the Mega Hack, if cdparanoia ever is fixed, or we
    use another ripping library we can remove this.  */
 #include <linux/cdrom.h>
 #include <sys/ioctl.h>
 
-#if HAVE_LAME
-#include <lame/lame.h>
+}
 #endif
 
-}
 #include <kdebug.h>
 #include <kurl.h>
 #include <kprotocolmanager.h>
@@ -91,6 +105,16 @@ extern "C"
 
 int start_of_first_data_as_in_toc;
 int hack_track;
+
+#ifdef __FreeBSD__
+/* The code found in FreeBSD's port of cdparanoia 3.9.8_4 has
+** pretty much the same functionality, except it is documented.
+** In addition, the multisession hack stuff is #ifdeffed out
+** in the port, so presumably (a) it never happes or (b) the
+** TOC returned by the BSD driver works differently or (c) we
+** just don't care over there.
+*/
+#else
 /* Mega hack.  This function comes from libcdda_interface, and is called by
    it.  We need to override it, so we implement it ourself in the hope, that
    shared lib semantics make the calls in libcdda_interface to FixupTOC end
@@ -151,6 +175,7 @@ int FixupTOC(cdrom_drive *d, int tracks)
   }
   return 0;
 }
+#endif
 
 /* libcdda returns for cdda_disc_lastsector() the last sector of the last
    _audio_ track.  How broken.  For CDDB Disc-ID we need the real last sector
@@ -160,6 +185,7 @@ long my_last_sector(cdrom_drive *drive)
   return cdda_track_lastsector(drive, drive->tracks);
 }
 
+
 enum Which_dir { Unknown = 0, Device, ByName, ByTrack, Title, Info, Root,
                  MP3, Vorbis };
 
@@ -228,8 +254,8 @@ CdConfigImp::CdConfigImp( QWidget* parent, const char* name):CdConfig(parent,nam
   databaseServer->setText(config.readEntry("databaseServer", "freedb.freedb.org"));
   databasePort->setValue(config.readNumEntry("databasePort", 8880));
   performCDDBauto->setChecked(config.readBoolEntry("performCDDBauto", false));
-  bool constantlyScan = config.readBoolEntry("constantlyScan", false); 
- 
+  bool constantlyScan = config.readBoolEntry("constantlyScan", false);
+
   //attemptToListAlbu/m();
   updating = false;
 
@@ -305,7 +331,7 @@ CdConfigImp::initRequest(const KURL & url)
 
   if (0 == drive)
   {
-    
+
     //error(KIO::ERR_DOES_NOT_EXIST, url.path());
     return 0;
   }
@@ -437,7 +463,7 @@ CdConfigImp::updateCD(struct cdrom_drive * drive)
   //BEN TODO
   //if (id == d->discid)
   //  return -1;
-  
+
   d->discid = id;
   d->tracks = cdda_tracks(drive);
   d->cd_title = i18n("Unknown Album");
@@ -498,7 +524,7 @@ CdConfigImp::updateCD(struct cdrom_drive * drive)
 
 /**
  * Attempt to list the files.
- */ 
+ */
 void CdConfigImp::attemptToListAlbum(){
   KURL url = "/";
   struct cdrom_drive *drive = pickDrive();
@@ -682,8 +708,8 @@ void CdConfigImp::getParameters() {
 
   int method = config->readNumEntry("encmethod",0);
 
-  if (method == 0) { 
-    
+  if (method == 0) {
+
     // Constant Bitrate Encoding
     lame_set_VBR(d->gf, vbr_off);
     lame_set_brate(d->gf,config->readNumEntry("cbrbitrate",160));
@@ -691,9 +717,9 @@ void CdConfigImp::getParameters() {
     lame_set_quality(d->gf, quality);
 
   } else {
-    
+
     // Variable Bitrate Encoding
-    
+
     if (config->readBoolEntry("set_vbr_avr",true)) {
 
       lame_set_VBR(d->gf,vbr_abr);
@@ -705,16 +731,16 @@ void CdConfigImp::getParameters() {
 
       if (lame_get_VBR(d->gf) == vbr_off) lame_set_VBR(d->gf, vbr_default);
 
-      if (config->readBoolEntry("set_vbr_min",true)) 
+      if (config->readBoolEntry("set_vbr_min",true))
 	lame_set_VBR_min_bitrate_kbps(d->gf, config->readNumEntry("vbr_min_bitrate",0));
       if (config->readBoolEntry("vbr_min_hard",true))
 	lame_set_VBR_hard_min(d->gf, 1);
-      if (config->readBoolEntry("set_vbr_max",true)) 
+      if (config->readBoolEntry("set_vbr_max",true))
 	lame_set_VBR_max_bitrate_kbps(d->gf, config->readNumEntry("vbr_max_bitrate",0));
 
       d->bitrate = 128;
       lame_set_VBR_q(d->gf, quality);
-      
+
     }
 
     lame_set_bWriteVbrTag(d->gf, config->readBoolEntry("write_xing_tag",true));
