@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_m3u.cpp,v 1.12 2002/11/17 23:03:46 lukas Exp $
+ *  $Id: kfile_m3u.cpp,v 1.12.2.1 2003/06/01 07:49:06 lukas Exp $
  */
 
 #include "kfile_m3u.h"
@@ -55,7 +55,7 @@ KM3uPlugin::KM3uPlugin( QObject *parent, const char *name,
 bool KM3uPlugin::readInfo( KFileMetaInfo& info, uint )
 {
     QFile f(info.path());
-    f.open(IO_ReadOnly);
+    if (!f.open(IO_ReadOnly)) return false;
     QTextStream str(&f);
     str.setEncoding(QTextStream::Locale);
     
