@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_ogg.cpp,v 1.22.2.2 2002/12/31 14:25:21 pfeiffer Exp $
+ *  $Id: kfile_ogg.cpp,v 1.22.2.3 2003/03/24 18:37:23 binner Exp $
  */
 
 #include "kfile_ogg.h"
@@ -85,7 +85,32 @@ KOggPlugin::KOggPlugin( QObject *parent, const char *name,
     item = addItemInfo(group, "Title", i18n("Title"), QVariant::String);
     setHint(item, KFileMimeTypeInfo::Name);
     setAttributes(item, KFileMimeTypeInfo::Modifiable);
-   
+
+    item = addItemInfo(group, "Album", i18n("Album"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Genre", i18n("Genre"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Tracknumber", i18n("Track Number"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Date", i18n("Date"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Description", i18n("Description"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Organization", i18n("Organization"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Location", i18n("Location"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+    item = addItemInfo(group, "Copyright", i18n("Copyright"), QVariant::String);
+    setAttributes(item, KFileMimeTypeInfo::Modifiable);
+
+
     addVariableInfo(group, QVariant::String, KFileMimeTypeInfo::Addable |
                                              KFileMimeTypeInfo::Removable |
                                              KFileMimeTypeInfo::Modifiable); 
