@@ -605,6 +605,12 @@ bool AudioCDProtocol::initLameLib(){
 struct cdrom_drive *
 AudioCDProtocol::initRequest(const KURL & url)
 {
+  if (url.hasHost())
+  {
+    error(KIO::ERR_DOES_NOT_EXIST, url.path());
+    return 0;
+  }
+
 
 #ifdef HAVE_LAME
   initLameLib();
@@ -797,48 +803,34 @@ AudioCDProtocol::get(const KURL & url)
   {
     QString trackName(d->titles[trackNumber - 1].mid(3));
 
-    vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("title"),
-       const_cast<char *>(trackName.utf8().data())
-      );
+    typedef QPair<QCString, QString> CommentField;
+    QValueList<CommentField> commentFields;
+    
+    commentFields.append(CommentField("title", trackName));
+    commentFields.append(CommentField("artist", d->cd_artist));
+    commentFields.append(CommentField("album", d->cd_title));
+    commentFields.append(CommentField("genre", d->cd_category));
+    commentFields.append(CommentField("tracknumber", QString::number(d->req_track+1)));
 
-    vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("artist"),
-       const_cast<char *>(d->cd_artist.utf8().data())
-      );
+    if (d->cd_year > 0) {
+      QDateTime dt = QDate(d->cd_year, 1, 1);
+      commentFields.append(CommentField("date", dt.toString(Qt::ISODate).utf8().data()));
+    }
 
-    vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("album"),
-       const_cast<char *>(d->cd_title.utf8().data())
-      );
+    for(QValueListIterator<CommentField> it = commentFields.begin(); it != commentFields.end(); ++it) {
+      
+      // if the value is not empty
+      if(!(*it).second.isEmpty()) {
 
-    vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("genre"),
-       const_cast<char *>(d->cd_category.utf8().data())
-      );
+        char *key = qstrdup((*it).first);
+        char *value = qstrdup((*it).second.utf8().data());
 
-    vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("tracknumber"),
-       const_cast<char *>(QString::number(trackNumber).utf8().data())
-      );
-
-     QDateTime dt = QDate(d->cd_year, 1, 1);
-     vorbis_comment_add_tag
-      (
-       &d->vc,
-       const_cast<char *>("date"),
-       const_cast<char *>(dt.toString(Qt::ISODate).utf8().data())
-      );
+        vorbis_comment_add_tag(&d->vc, key, value);
+        
+        delete [] key;
+        delete [] value;
+      }
+    }
   }
 #endif
 
@@ -859,8 +851,8 @@ AudioCDProtocol::get(const KURL & url)
 
 #ifdef HAVE_VORBIS
   if (filetype == "ogg") {
-    totalSize((time_secs * d->vorbis_bitrate)/8);
-    mimeType("audio/x-ogg-vorbis");
+    totalSize( vorbisSize(time_secs) );
+    mimeType("application/x-ogg");
   }
 #endif
 
@@ -938,7 +930,7 @@ AudioCDProtocol::stat(const KURL & url)
 
 #ifdef HAVE_VORBIS
       if (filetype == "ogg")
-        atom.m_long = (length_seconds * d->vorbis_bitrate) / 8;
+        atom.m_long = vorbisSize(length_seconds);
 #endif
 
       if (filetype == "cda") atom.m_long = filesize;
@@ -1077,6 +1069,42 @@ app_file(UDSEntry& e, const QString & n, size_t s)
   app_entry(e, KIO::UDS_SIZE, s);
 }
 
+#ifdef HAVE_VORBIS
+  long
+AudioCDProtocol::vorbisSize(long time_secs)
+{
+  long vorbis_size;
+  switch (d->vorbis_encode_method)
+  {
+  case 0: // quality based encoding
+
+#if HAVE_VORBIS >= 2 // If really old Vorbis is being used, skip this nicely.
+
+  {
+    // Estimated numbers based on the Vorbis FAQ:
+    // http://www.xiph.org/archives/vorbis-faq/200203/0030.html
+    
+    static long vorbis_q_bitrate[] = { 60,  74,  86,  106, 120, 152, 
+				       183, 207, 239, 309, 440 };
+    long quality = static_cast<long>(d->vorbis_quality);
+    if (quality < 0 || quality > 10) 
+      quality = 3;
+    vorbis_size = (time_secs * vorbis_q_bitrate[quality] * 1000) / 8;
+
+    break;
+  }
+
+#endif // HAVE_VORBIS >= 2
+
+  default: // bitrate based encoding
+    vorbis_size = (time_secs * d->vorbis_bitrate/8);
+    break;
+  }
+
+  return vorbis_size;
+}
+#endif
+
   void
 AudioCDProtocol::listDir(const KURL & url)
 {
@@ -1183,7 +1211,7 @@ AudioCDProtocol::listDir(const KURL & url)
 #ifdef HAVE_VORBIS
             case Vorbis:
               name = d->titles[i - 1] + s3;
-              size = (length_seconds * d->vorbis_bitrate) / 8; // length * bitrate / 8; 
+              size = vorbisSize(length_seconds); 
               break;
 #endif
 
@@ -1346,6 +1374,11 @@ AudioCDProtocol::parseArgs(const KURL & url)
 
 }
 
+inline int16_t swap16 (int16_t i)
+{
+  return (((i >> 8) & 0xFF) | ((i << 8) & 0xFF00));
+}
+
   void
 AudioCDProtocol::paranoiaRead(
     struct cdrom_drive * drive,
@@ -1525,6 +1558,12 @@ static char mp3buffer[mp3buffer_size];
 
       if (filetype == "wav" || filetype == "cda") {
         QByteArray output;
+        int16_t i16 = 1;
+        /* WAV is defined to be little endian, so we need to swap it
+           on big endian platforms.  */
+        if (((char*)&i16)[0] == 0)
+          for (int i=0; i < 2 * CD_FRAMESAMPLES; i++)
+            buf[i] = swap16 (buf[i]);
         char * cbuf = reinterpret_cast<char *>(buf);
         output.setRawData(cbuf, CD_FRAMESIZE_RAW);
         data(output);
@@ -1619,7 +1658,7 @@ void AudioCDProtocol::getParameters() {
      int method = config->readNumEntry("encmethod",0);
     
      if (method == 0) { 
-       
+
        // Constant Bitrate Encoding
        (_lamelib_lame_set_VBR)(d->gf, vbr_off);
        (_lamelib_lame_set_brate)(d->gf,config->readNumEntry("cbrbitrate",160));
@@ -1705,7 +1744,7 @@ void AudioCDProtocol::getParameters() {
 
   config->setGroup("Vorbis");
 
-  d->vorbis_encode_method = config->readNumEntry("encmethod", 0); // 0 for quality, 1 for managed bitrate
+  d->vorbis_encode_method = config->readNumEntry("encmethod", 1); // 0 for quality, 1 for managed bitrate
   d->vorbis_quality = config->readDoubleNumEntry("quality",3.0); // default quality level of 3, to match oggenc
 
   if ( config->readBoolEntry("set_vorbis_min_bitrate",false) ) {
