@@ -17,19 +17,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
 #ifndef _channelcfgdlg_h_
 #define _channelcfgdlg_h_
 
-#include <qdialog.h>
+#include <kdialogbase.h>
 
-class QButtonGroup;
-class QPushButton;
+class QVButtonGroup;
 class QRadioButton;
-class ChannelViewConfigDialog : public QDialog
+class ChannelViewConfigDialog : public KDialogBase
 {
     Q_OBJECT
 
@@ -38,13 +37,10 @@ public:
     ChannelViewConfigDialog(QWidget *parent,const char *name);
     
 private:
-    QButtonGroup *qbg;
+    QVButtonGroup *qbg;
     QRadioButton *rb0;
     QRadioButton *rb1;
-    
-    QPushButton *ok;
-    QPushButton *cancel;
-    
+        
 public slots:
     void modeselected(int idx);
 
