@@ -1,6 +1,6 @@
 /*
  *
- * $Id: configdlg.h,v 1.10 2000/08/27 22:06:30 greglee Exp $
+ * $Id: configdlg.h,v 1.11 2002/05/18 11:50:17 gioele Exp $
  *
  * kscd -- A simple CD player for the KDE project           
  *
@@ -43,7 +43,7 @@
 #include <qlayout.h>
 #include <kbuttonbox.h>
 #include <knuminput.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 //#include <khelpmenu.h>
 #include <qwhatsthis.h>
 
