@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: table.cpp,v 1.8 2001/04/12 09:08:31 garbanzo Exp $
+** $Id: table.cpp,v 1.9 2001/09/02 20:55:16 bruggie Exp $
 **
 ** Copyright (C) 1992-1999 Troll Tech AS.  All rights reserved.
 **
@@ -26,7 +26,7 @@ static const int NUMROWS = 17;
 */
 
 Table::Table( int width, int height, QWidget *parent, const char *name, WFlags f)
-    : QTableView(parent,name,f)
+    : QtTableView(parent,name,f)
 {
     int n;
 
