@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef MIXDEVICEWIDGET_H
@@ -28,7 +28,7 @@
 #include <kpanelapplet.h>
 
 #include <qwidget.h>
-#include <volume.h>
+#include "volume.h"
 #include <qptrlist.h>
 #include <qpixmap.h>
 #include <qrangecontrol.h>
@@ -44,6 +44,7 @@ class QTimer;
 class KSmallSlider;
 class QSlider;
 class KGlobalAccel;
+class VerticalText;
 
 class MixDeviceWidget
  : public QWidget
@@ -127,7 +128,8 @@ class MixDeviceWidget
       QLabel *m_iconLabel;
       KLedButton *m_muteLED;
       KLedButton *m_recordLED;
-      QLabel *m_label;
+      //QLabel *m_label;
+      VerticalText *m_label;
 
 };
 
