@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: kscd.cpp,v 1.176.2.1 2002/11/28 21:35:27 mueller Exp $
+ * $Id: kscd.cpp,v 1.176.2.5 2003/07/04 15:14:14 wstephens Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -202,6 +202,7 @@ KSCD::KSCD( QWidget *parent, const char *name )
   cddialog            = 0L;
   configDialog        = 0L;
   jumpToTrack         = 0L;
+  random_current      = random_list.begin();
 
   smtpConfigData = new SMTPConfigData;
 
@@ -405,7 +406,7 @@ KSCD::initCDROM()
   if(cddrive_is_ok)
     volChanged(volume);
 
-  if (autoplay)
+  if (autoplay && cur_cdmode != WM_CDM_PLAYING)
   {
     playClicked();
   }
@@ -938,15 +939,14 @@ KSCD::nextClicked()
             playlistpointer = 0;
 
         cur_track = atoi( (*playlist.at(playlistpointer)).ascii() );
-        wm_cd_play(cur_track, 0, cur_track + 1);
+        wm_cd_play(cur_track, 0, cur_ntracks + 1);
     }
     else
     {
         if (cur_track == cur_ntracks)
             cur_track = 0;
 
-        // TODO: determine if this should indeed be cur_track + 2?
-        wm_cd_play (cur_track + 1, 0, cur_track + 2);
+        wm_cd_play (cur_track + 1, 0, cur_ntracks + 1);
     }
 } // nextClicked()
 
@@ -1021,8 +1021,15 @@ KSCD::quitClicked()
 void
 KSCD::closeEvent( QCloseEvent *e )
 {
-    // Stop playing the CD
-    if ( cur_cdmode == WM_CDM_PLAYING )
+    if (docking)
+    {
+        hide();
+        e->ignore();
+        return;
+    }
+
+    /* Stop playing the CD */
+    if ( stopexit && cur_cdmode == WM_CDM_PLAYING )
         stopClicked();
 
     writeSettings();
@@ -1035,7 +1042,8 @@ KSCD::closeEvent( QCloseEvent *e )
     qApp->processEvents();
     qApp->flushX();
 
-    if(stopexit)
+    // TODO: is this really necessary given the stopClicked() above?
+    if (stopexit)
         wm_cd_stop ();
 
     wm_cd_status();
@@ -1129,7 +1137,7 @@ KSCD::randomSelected()
         else
             statuslabel->setText(i18n("Random"));
 
-        if(songListCB->count()==0)
+        if(cur_ntracks < 1)
             return;
         make_random_list(); /* koz: Build a unique, once, random list */
         nextClicked();
@@ -1298,8 +1306,6 @@ KSCD::setDocking(bool dock)
     docking = dock;
     if(docking)
     {
-        //TODO: make it skip the taskbar when minimized something like:
-        //KWin::setState(winId(), KWin::info(winId()).state | NET::SkipTaskbar);
         dock_widget->show();
         connect(this, SIGNAL(trackChanged(const QString&)),
                 dock_widget, SLOT(setToolTip(const QString&)));
@@ -1350,8 +1356,13 @@ KSCD::randomtrack()
     /* koz: 15/01/00. Check to see if we want to do a randomonce. If so */
     /* we execute the first set of statements. Else we execute the second */
     /* set, the original code.  */
-    if( randomonce  )
+    if( randomonce )
     {
+        if ( random_list.isEmpty() )
+        {
+            return -1;
+        }
+
         if ( random_current == random_list.end() )
         {
             // playing the same random list isn't very random, is it?
@@ -2379,7 +2390,7 @@ KSCD::setArtistAndTitle(const QString& artist, const QString& title)
 
     if (!title.isEmpty()) {
         titlelabel->setText(title);
-        tooltip += KStringHandler::rsqueeze(title,30);
+        tooltip += KStringHandler::rsqueeze(title, 30);
     }
     else {
         titlelabel->clear();
@@ -3076,6 +3087,12 @@ KSCD::jumpTracks()
     jumpToTrack = 0;
 } // jumpTracks
 
+bool
+KSCD::playing()
+{
+    return ( cur_cdmode == WM_CDM_PLAYING );
+}
+
 int KSCD::currentTrack()
 {
     return cur_track;
