@@ -1,6 +1,6 @@
 /*
 
-  $Id: main.cpp,v 1.15 2000/08/11 15:44:48 faure Exp $
+  $Id: main.cpp,v 1.16 2002/05/14 09:47:52 gioele Exp $
 
   kscdmagic 2.0   Dirk Frsterling <milliByte@gmx.de>
 
@@ -52,7 +52,7 @@
 
 #include <klocale.h>
 #include <kglobal.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaboutdata.h>
 #include <dcopclient.h>
 #include <kcmdlineargs.h>
