@@ -1,7 +1,7 @@
 #ifndef WM_STRUCT_H
 #define WM_STRUCT_H
 /*
- * $Id: wm_struct.h,v 1.3 2001/06/18 11:01:07 dfoerste Exp $
+ * $Id: wm_struct.h,v 1.4 2001/10/04 18:05:21 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -113,7 +113,8 @@ enum wm_cd_modes
   WM_CDM_PAUSED = 3,
   WM_CDM_STOPPED = 4,
   WM_CDM_EJECTED = 5,
-  WM_CDM_DEVICECHANGED = 66
+  WM_CDM_DEVICECHANGED = 66,
+  WM_CDM_NO_DISC = 67
 };
 
 /*
