@@ -19,8 +19,7 @@
 #define __OUTPUTINTERFACE_H
 
 #include <pthread.h>
-#include <iostream.h>
-#include <fstream.h>
+#include <fstream>
 #include "buffer.h"
 
 // uncomment this for debugging the output stream
@@ -33,13 +32,13 @@ class OutputInterface {
   int protocolSyntax;
   int nr;
   Buffer* outBuffer;
-  ostream* out;
+  std::ostream* out;
   pthread_mutex_t writeOutMut;
 
 
  public:
 
-  OutputInterface(ostream* out);
+  OutputInterface(std::ostream* out);
   ~OutputInterface();
 
 
