@@ -22,7 +22,9 @@
 
 
 
-#include <iostream.h>
+#include <iostream>
+using namespace std;
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
