@@ -14,7 +14,9 @@
 
 #include "cdromToc.h"
 
+#include <iostream>
 
+using namespace std;
 
 CDRomToc::CDRomToc() {
   maxEntries=0;
