@@ -13,6 +13,10 @@
 
 #include "pluginInfo.h"
 
+#include <iostream>
+
+using namespace std;
+
 
 PluginInfo::PluginInfo() {
   musicName=new DynBuffer(20);
