@@ -1,5 +1,5 @@
 /*
- * $Id: mpg123PlayObject_impl.cpp,v 1.23 2001/08/23 17:21:36 waba Exp $
+ * $Id: mpg123PlayObject_impl.cpp,v 1.24 2002/10/27 01:04:54 pfeiffer Exp $
  * Copyright (C) 2001 Kevin Puetz
  *
  *
@@ -288,7 +288,7 @@ mpg123PlayObject_impl::mpg123PlayObject_impl()
 	//memset(&mp->fr, 0, sizeof(struct frame)); XXX: why would I need to do this?
 
 	prgName = strdup("arts/mpg123");
-	prgVersion = strdup("$Revision: 1.23 $");
+	prgVersion = strdup("$Revision: 1.24 $");
 	pcm_point = 0;
 	pcm_sample=pcm_buf; // just point this to our internal buffer
 	memset(&param, 0, sizeof(struct parameter));
@@ -536,7 +536,7 @@ poCapabilities mpg123PlayObject_impl::capabilities()
 //YYY
 string mpg123PlayObject_impl::mediaName()
 {
-	return "";
+	return param.filename;
 }
 
 poState mpg123PlayObject_impl::state()
