@@ -51,7 +51,7 @@ private slots:
 
 private:
 	QCheckBox *mAutoPlay, *mLoopList, *mOneInstance, *mRememberPositions,
-	          *mClearOnOpen, *mHackUpPlaylist, *mFastVolume;
+	          *mClearOnStart, *mClearOnOpen, *mHackUpPlaylist, *mFastVolume;
 	KURLRequester *mDlSaver;
 	KLineEdit *mTitleFormat;
 };
