@@ -14,7 +14,7 @@ class MetaTagLoader:public QObject, public Tags, public Plugin {
   Q_OBJECT
   public:
     MetaTagLoader();
-    virtual ~ MetaTagLoader();
+    ~MetaTagLoader();
 
   public slots:
     bool update(PlaylistItem & item);
