@@ -10,29 +10,31 @@
 
 // Abandon All Hope, Ye Who Enter Here
 
-
+#include <qdragobject.h>
+#include <qheader.h>
+#include <qlayout.h>
 #include <qmap.h>
 #include <qregexp.h>
-
-#include <qlayout.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kstdaction.h>
-#include <qheader.h>
-#include <qdragobject.h>
-#include <kaction.h>
-#include <kmenubar.h>
-#include <kfiledialog.h>
 #include <qtextstream.h>
+
+#include <kaction.h>
+#include <kdebug.h>
+#include <kfiledialog.h>
+#include <kfileitem.h>
+#include <kio/job.h>
+#include <kio/netaccess.h>
+#include <klocale.h>
+#include <kmenubar.h>
+#include <ksimpleconfig.h>
+#include <kstandarddirs.h>
+#include <kstdaction.h>
+#include <kedittoolbar.h>
+#include <kurldrag.h>
+#include <kmessagebox.h>
+
 #include <noatun/app.h>
 #include <noatun/player.h>
 #include <noatun/playlistsaver.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
-#include <kfileitem.h>
-#include <ksimpleconfig.h>
-#include <kstandarddirs.h>
-#include <kurldrag.h>
 
 #include "playlist.h"
 #include "view.h"
@@ -48,7 +50,9 @@ SafeListViewItem::SafeListViewItem(QListView *parent, QListViewItem *after, cons
 
 	static_cast<KListView*>(parent)->moveItem(this, 0, after);
 	setOn(true);
-	setText(0,text.filename());
+
+	// is this really needed, it makes the listview too wide for me :(
+//	setText(0,text.filename());
 
 	//	if (!isDownloaded()) setText(1, "0%");
 
@@ -74,13 +78,28 @@ SafeListViewItem::SafeListViewItem(QListView *parent, QListViewItem *after, cons
 	addRef();
 
 	setOn(true);
+
+	// A version of setProperty that assumes a key is unique,
+	// and doesn't call modified for every new key.
+	// Ugly, but this function is a very hot path on playlist loading
 	for (QMap<QString,QString>::ConstIterator i=props.begin(); i!=props.end(); ++i )
 	{
-		setProperty(i.key(), i.data());
+		QString n = i.key();
+		QString val = i.data();
+
+		if (n=="enabled")
+		{
+			setOn(val!="false" && val!="0");
+		}
+		else
+		{
+			Property p={n,val};
+			mProperties += p;
+		}
 	}
 
 	static_cast<KListView*>(parent)->moveItem(this, 0, after);
-	setText(0,title());
+	modified();
 
 	//	if (!isDownloaded()) setText(1, "0%");
 
@@ -113,7 +132,11 @@ SafeListViewItem::~SafeListViewItem()
 		SPL->setCurrent(0);
 	}
 	else if (napp->player()->current()==this)
-		napp->player()->forward();
+	{
+		SPL->setCurrent(0);
+		if (!SPL->exiting())
+			napp->player()->forward();
+	}
 
 	if (SPL->nextItem==this)
 		SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
@@ -135,6 +158,57 @@ QString SafeListViewItem::file() const
 	return localFilename();
 }
 
+static void pad(QString &str)
+{
+	int len=str.length();
+	int at = 0;
+	int blocklen=0;
+
+	static const int paddingsize=12;
+	
+	// not static for reason
+	const QChar chars[paddingsize] = 
+	{
+		QChar('0'), QChar('0'), QChar('0'), QChar('0'),
+		QChar('0'), QChar('0'), QChar('0'), QChar('0'),
+		QChar('0'), QChar('0'), QChar('0'), QChar('0')
+	};
+	
+	for (int i=0; i < len; i++)
+	{
+		if (str[i].isNumber())
+		{
+			if (!blocklen)
+				at = i;
+			blocklen++;
+		}
+		else if (blocklen)
+		{
+			int pads=paddingsize;
+			pads -= blocklen;
+			str.insert(at, chars, pads);
+			i += pads;
+			blocklen = 0;
+		}
+	}
+	if (blocklen)
+	{
+		int pads=paddingsize;
+		pads -= blocklen;
+		str.insert(at, chars, pads);
+	}
+}
+
+int SafeListViewItem::compare(QListViewItem * i, int col, bool) const
+{
+	QString text1 = text(col);
+	QString text2 = i->text(col);
+
+	pad(text1);
+	pad(text2);
+	return text1.compare(text2);
+}
+
 QString SafeListViewItem::property(const QString &n, const QString &def) const
 {
 	for (QValueList<Property>::ConstIterator i=mProperties.begin(); i != mProperties.end(); ++i)
@@ -158,6 +232,12 @@ void SafeListViewItem::setProperty(const QString &n, const QString &val)
 	}
 	else
 	{
+		if ( property(n,"") == val )
+		{
+//			kdDebug(66666) << "SafeListViewItem::setProperty(), property unchanged!" << endl;
+			return;
+		}
+
 		clearProperty(n);
 		Property p={n,val};
 		mProperties += p;
@@ -222,9 +302,23 @@ void SafeListViewItem::downloadFinished()
 
 void SafeListViewItem::modified()
 {
-	setText(0, title());
-	if (isDownloaded() && length()!=-1)
+	bool widthChangeNeeded = false;
+	
+	if (text(0)!=title())
+	{
+		setText(0, title());
+		widthChangeNeeded = true;
+	}
+	
+	if (isDownloaded() && length()!=-1 && text(1)!=lengthString())
+	{
 		setText(1, lengthString());
+		widthChangeNeeded = true;
+	}
+	
+	if (widthChangeNeeded)
+		widthChanged(-1);
+
 	PlaylistItemData::modified();
 }
 
@@ -262,6 +356,7 @@ List::List(View *parent)
 	connect(this, SIGNAL(dropped(QDropEvent*, QListViewItem*)), SLOT(dropEvent(QDropEvent*, QListViewItem*)));
 	connect(this, SIGNAL(moved(QPtrList<QListViewItem>&,QPtrList<QListViewItem>&,QPtrList<QListViewItem>&)), SLOT(move(QPtrList<QListViewItem>&,QPtrList<QListViewItem>&,QPtrList<QListViewItem>&)));
 	connect(this, SIGNAL(aboutToMove()), parent, SLOT(setNoSorting()));
+	connect(this, SIGNAL(deleteCurrentItem()), parent, SLOT(deleteSelected()));
 }
 
 List::~List()
@@ -332,12 +427,24 @@ void List::viewportPaintEvent(QPaintEvent *e)
 
 void List::keyPressEvent(QKeyEvent *e)
 {
-	if (e->key()==Qt::Key_Enter || e->key()==Key_Return)
+	if (e->key()==Key_Enter || e->key()==Key_Return)
 	{
 		if (currentItem())
 		{
-			emit QListView::doubleClicked(currentItem());
+			emit KListView::executed(currentItem());
 		}
+
+		return;
+	}
+
+	if (e->key()==Key_Delete)
+	{
+		if (currentItem())
+		{
+			emit deleteCurrentItem();
+		}
+
+		return;
 	}
 
 	KListView::keyPressEvent(e);
@@ -538,41 +645,39 @@ void List::slotRedirection(KIO::Job *, const KURL & url)
 	currentJobURL= url;
 }
 
+/////////////////////////////////
+
 View::View(SplitPlaylist *)
 	: KMainWindow(0,0)
 {
 	list=new List(this);
-	list->show();
 	setCentralWidget(list);
 	connect(list, SIGNAL(modified(void)), this, SLOT(setModified(void)) );
 	// connect the click on the header with sorting
 	connect(list->header(),SIGNAL(clicked(int)),this,SLOT(headerClicked(int)) );
 
-	tb = new KToolBar( this );
-	addToolBar(tb);
+	mOpen=new KAction(i18n("Add &Files..."), "queue", 0, this, SLOT(addFiles()), actionCollection(), "add_files");
+	(void) new KAction(i18n("Add &Directories..."), "folder", 0, this, SLOT(addDirectory()),  actionCollection(), "add_dir");
+	mDelete=new KAction(i18n("Delete"), "editdelete", Key_Delete, this, SLOT(deleteSelected()),  actionCollection(), "delete");
 
-	(mOpen=new KAction(i18n("Add &Files"), "queue", 0, this, SLOT(addFiles()),this, "open"))->plug(tb);
-	(new KAction(i18n("Add &Directories"), "folder", 0, this, SLOT(addDirectory()), this, "add_dir"))->plug(tb);
-	(mDelete=new KAction(i18n("Delete"), "editdelete", Qt::Key_Delete, this, SLOT(deleteSelected()), this, "delete"))->plug(tb);
+	mClose=KStdAction::close(this, SLOT(close()), actionCollection());
+	mFind=KStdAction::find(this, SLOT(find()), actionCollection());
 
-	(new KActionSeparator(this))->plug(tb);
+	(void) KStdAction::configureToolbars(this, SLOT(configureToolBars()), actionCollection());
+	mOpenNew=KStdAction::openNew(this, SLOT(openNew()), actionCollection());
+	mOpenpl=KStdAction::open(this, SLOT(open()), actionCollection());
+	mSave=KStdAction::save(this, SLOT(save()), actionCollection());
+	mSaveAs=KStdAction::saveAs(this, SLOT(saveAs()), actionCollection());
 
-	(mFind=KStdAction::find(this, SLOT(find()), actionCollection(), "find"))->plug(tb);
+	(void) new KAction(i18n("Shuffle"), "misc", 0, SPL, SLOT( randomize() ), actionCollection(), "shuffle");
+	(void) new KAction(i18n("Clear"), "fileclose", 0, list, SLOT( clear() ), actionCollection(), "clear");
 
-	(new KActionSeparator(this))->plug(tb);
-
-	(mOpenNew=KStdAction::openNew(this, SLOT(openNew()), actionCollection(), "openNew"))->plug(tb);
-	(mOpenpl=KStdAction::open(this, SLOT(open()), actionCollection(), "open"))->plug(tb);
-	(mSave=KStdAction::save(this, SLOT(save()), actionCollection(), "save"))->plug(tb);
-	(mSaveAs=KStdAction::saveAs(this, SLOT(saveAs()), actionCollection(), "saveas"))->plug(tb);
-
-	(new KActionSeparator(this))->plug(tb);
-
-	(new KAction(i18n("Shuffle"), "misc", 0, SPL, SLOT( randomize() ), actionCollection(), "clear"))->plug(tb);
-	(new KAction(i18n("Clear"), "fileclose", 0, list, SLOT( clear() ), actionCollection(), "clear"))->plug(tb);
-	list->setFocus();
+	createGUI("splui.rc");
 
 	mFinder = new Finder(this);
+
+	applyMainWindowSettings(KGlobal::config(), "SPL Window");
+	list->setFocus();
 }
 
 void View::find()
@@ -617,20 +722,24 @@ void View::findIt(Finder *f)
 {
 	QListViewItem *search=list->currentItem();
 
-	if (!search)
+	if (list->currentItem())
+	{
+		if (f->isForward())
+			search=list->currentItem()->itemBelow();
+		else
+			search=list->currentItem()->itemAbove();
+	}
+	else
+	{
 		if (f->isForward())
 			search=list->firstChild();
 		else
 			search=list->lastChild();
+	}
+
 
 	while (search)
 	{
-		if (f->isForward())
-			search=search->itemBelow();
-		else
-			search=search->itemAbove();
-
-		if (!search) return;
 		if (f->regexp())
 		{
 			if (testWord(search, QRegExp(f->string(), false)))
@@ -642,6 +751,24 @@ void View::findIt(Finder *f)
 				break;
 		}
 
+		if (f->isForward())
+			search=search->itemBelow();
+		else
+			search=search->itemAbove();
+
+		if (!search)
+		{
+			if (f->isForward())
+			{
+				if (KMessageBox::questionYesNo(this, i18n("End of playlist reached. Continue searching from beginning?")) == KMessageBox::Yes)
+					search=list->firstChild();
+			}
+			else
+			{
+				if (KMessageBox::questionYesNo(this, i18n("Beginning of playlist reached. Continue searching from end?")) == KMessageBox::Yes)
+					search=list->lastChild();
+			}
+		}
 	}
 
 	if (search)
@@ -663,9 +790,6 @@ View::~View()
 	hide();
 	saveState();
 	delete list;
-	delete tb;
-	mOpen->unplug(tb);
-	mDelete->unplug(tb);
 }
 
 void View::init()
@@ -673,7 +797,6 @@ void View::init()
 	// see if we are importing an old-style list
 	bool importing= ! QFile(napp->dirs()->saveLocation("data", "noatun/") + "splitplaylist.xml").exists();
 	
-	
 	if (importing)
 	{
 		KURL internalURL;
@@ -760,7 +883,7 @@ void View::deleteSelected()
 
 void View::addFiles()
 {
-	KURL::List files=KFileDialog::getOpenURLs(0, napp->mimeTypes(), this, i18n("Select a File to Play"));
+	KURL::List files=KFileDialog::getOpenURLs(0, napp->mimeTypes(), this, i18n("Select File to Play"));
 
 	QListViewItem *last = list->lastItem();
 	for(KURL::List::Iterator it=files.begin(); it!=files.end(); ++it)
@@ -771,7 +894,7 @@ void View::addFiles()
 
 void View::addDirectory()
 {
-	QString file=KFileDialog::getExistingDirectory(0, this, i18n("Select a Directory"));
+	QString file=KFileDialog::getExistingDirectory(0, this, i18n("Select Directory"));
 
 	if (!file) return;
 	KURL url;
@@ -822,10 +945,25 @@ void View::saveState(void)
 		item=SPL->getAfter(item), i++;
 
 	config.writeEntry("current", i);
+	saveMainWindowSettings(KGlobal::config(), "SPL Window");
 
 	config.sync();
 }
 
+void View::configureToolBars()
+{
+	saveMainWindowSettings(KGlobal::config(), "SPL Window");
+	KEditToolbar dlg(actionCollection(), "splui.rc");
+	connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(newToolBarConfig()));
+	if (dlg.exec())
+		createGUI("splui.rc");
+}
+
+void View::newToolBarConfig()
+{
+	applyMainWindowSettings(KGlobal::config(), "SPL Window");
+}
+
 // turns the sorting on or off
 void View::setSorting(bool on, int column)
 {
@@ -847,7 +985,7 @@ void View::headerClicked(int column)
 	// we sort it again ascendingly this way, clicking on
 	// the header a second time will correctly toggle
 	// ascending/descending sort
-	if (list-> showSortIndicator())
+	if (list->showSortIndicator())
 	{
 		return;
 	}
