@@ -14,7 +14,6 @@
 #include <kconfig.h>
 #include <qstringlist.h>
 #include <kglobal.h>
-#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <khelpmenu.h>
@@ -23,7 +22,6 @@
 #include <kstdaction.h>
 #include <kaction.h>
 #include <qdragobject.h>
-#include <kstandarddirs.h>
 #include <kwin.h>
 #include <time.h>
 
@@ -137,6 +135,8 @@ WaSkin::WaSkin() : UserInterface()
 
 WaSkin::~WaSkin()
 {
+    delete waSkinManager;
+    waSkinManager = 0L;
 }
 
 void WaSkin::loadSkin(QString newSkinDir)
@@ -196,7 +196,7 @@ void WaSkin::createButtons()
     close = new WaButton(_WA_MAPPING_TITLE_CLOSE);
     close->setPixmapUp(_WA_SKIN_TITLE_CLOSE_NORM);
     close->setPixmapDown(_WA_SKIN_TITLE_CLOSE_PRES);
-    connect(close, SIGNAL(clicked()), this, SLOT(closeEvent()));
+    connect(close, SIGNAL(clicked()), this, SLOT(doClose()));
 
     shuffle->setTogglable(true);
     shuffle->show();
@@ -514,10 +514,14 @@ void WaSkin::shadeEvent()
         unshade();
 }
 
-void WaSkin::closeEvent() {
+void WaSkin::doUnload() {
     unload();
 }
 
+void WaSkin::doClose() {
+    QTimer::singleShot(0, this, SLOT(doUnload()));
+}
+
 void WaSkin::dragEnterEvent(QDragEnterEvent * event)
 {
     // accept uri drops only
